@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef VIEWERPLUGIN_H
-#define VIEWERPLUGIN_H
+#pragma once
 
-#include <QObject>
 #include "messageviewer_export.h"
+#include <QObject>
 class KActionCollection;
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class ViewerPluginPrivate;
 class ViewerPluginInterface;
 /**
@@ -23,7 +23,7 @@ class MESSAGEVIEWER_EXPORT ViewerPlugin : public QObject
     Q_OBJECT
 public:
     explicit ViewerPlugin(QObject *parent = nullptr);
-    ~ViewerPlugin();
+    ~ViewerPlugin() override;
 
     Q_REQUIRED_RESULT virtual MessageViewer::ViewerPluginInterface *createView(QWidget *parent, KActionCollection *ac) = 0;
     Q_REQUIRED_RESULT virtual QString viewerPluginName() const = 0;
@@ -40,4 +40,3 @@ private:
     ViewerPluginPrivate *const d;
 };
 }
-#endif // VIEWERPLUGIN_H
